@@ -3,8 +3,9 @@ BEGIN {
   $CPAN::Documentation::HTML::Entry::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $CPAN::Documentation::HTML::Entry::VERSION = '0.001';
+  $CPAN::Documentation::HTML::Entry::VERSION = '0.002';
 }
+# ABSTRACT: An entry (a module, binary or documentation) in the HTML
 
 use Moo;
 
@@ -40,19 +41,29 @@ __END__
 
 =head1 NAME
 
-CPAN::Documentation::HTML::Entry
+CPAN::Documentation::HTML::Entry - An entry (a module, binary or documentation) in the HTML
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Torsten Raudssus <torsten@raudss.us>
 
+=item *
+
+Doug Brown <doug@duckduckgo.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Torsten Raudssus.
+This software is copyright (c) 2013 by Torsten Raudssus & DuckDuckGo, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
